==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/sk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovať aspoň jedno malé a jedno veľké písmeno.",
    "Password needs to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné.",
    "Password policy" : "Politika hesla",
    "Minimal length" : "Minimálna dĺžka",
    "Forbid common passwords" : "Zakázať najpoužívanejšie heslá",
    "Enforce upper and lower case characters" : "Vynútiť veľké a malé znaky",
    "Enforce numeric characters" : "Vynútiť numerické znaky",
    "Enforce special characters" : "Vynútiť špeciálne znaky",
    "Password need to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Password need to contain at least one lower case character and one upper case character." : "Heslo musí obsahovať aspoň jeden malý znak a jeden veľký znak.",
    "Password need to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password need to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/sk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovať aspoň jedno malé a jedno veľké písmeno.",
    "Password needs to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné.",
    "Password policy" : "Politika hesla",
    "Minimal length" : "Minimálna dĺžka",
    "Forbid common passwords" : "Zakázať najpoužívanejšie heslá",
    "Enforce upper and lower case characters" : "Vynútiť veľké a malé znaky",
    "Enforce numeric characters" : "Vynútiť numerické znaky",
    "Enforce special characters" : "Vynútiť špeciálne znaky",
    "Password need to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Password need to contain at least one lower case character and one upper case character." : "Heslo musí obsahovať aspoň jeden malý znak a jeden veľký znak.",
    "Password need to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password need to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
